@@ -8,7 +8,7 @@ use namespace::autoclean;
 # debugging
 #use Smart::Comments '###', '####';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ of time (e.g. caching).  Builders are your friends :)
     use Moose::Role;
     use namespace::autoclean;
 
-    our $VERSION = '0.003';
+    our $VERSION = '0.004';
 
     has ttl => (is => 'ro', isa => 'Int', required => 1, predicate => 'has_ttl');
 
@@ -193,7 +193,7 @@ of time (e.g. caching).  Builders are your friends :)
     use Moose::Role;
     use namespace::autoclean;
 
-    our $VERSION = '0.003';
+    our $VERSION = '0.004';
 
     # debug!
     #before _eval_closure => sub { print "$_[2]\n" };
@@ -217,8 +217,23 @@ of time (e.g. caching).  Builders are your friends :)
             . ") {\n"
             ;
 
-        $code .= '    ' .$mi->inline_deinitialize_slot('$_[0]', $_) . ";\n"
-            for $attr->slots;
+        if ($attr->has_clearer) {
+
+            # if we have a clearer method, we should call that -- it may have
+            # been wrapped in the class
+
+            my $clearer = $attr->clearer;
+            ($clearer) = keys %$clearer if ref $clearer;
+
+            $code .= '$_[0]->' . $clearer . '()';
+
+        }
+        else {
+
+            # otherwise, just deinit all the slots we use
+            $code .= '    ' .$mi->inline_deinitialize_slot('$_[0]', $_) . ";\n"
+                for $attr->slots;
+        }
 
         $code .= "}\n";
 
